@@ -69,30 +69,8 @@ class BlogItem(models.Model):
         return '/B/{}'.format(self.id)
 
 
-class VideoItem(models.Model):
-    created_at = models.DateTimeField(auto_now_add=True)
-    published_at = models.DateTimeField(auto_now=True)
-    authorized = models.BooleanField(default=False)
-    author = models.ForeignKey('Author')
-    title = models.TextField(max_length=140)
-    video = models.URLField(max_length=280)
-    text = models.TextField()
-
-
-    def authorize(self):
-        self.authorized = True
-
-
-    def __unicode__(self):
-        return self.title
-
-
-    def get_url(self):
-        return '/V/{}'.format(self.id)
-
-
 def publication_destination(instance, filename):
-    return 'revuo/static/documents/' + '_'.join([str(hash(datetime.datetime.now())),filename])
+    return '_'.join([str(instance.author.id),filename])
 
 
 class Publication(models.Model):
@@ -113,9 +91,5 @@ class Publication(models.Model):
         return '/P/{}'.format(self.id)
 
 
-    def get_att_url(self):
-        return self.attachment.url[5:]
-
-
     def __unicode__(self):
         return self.title
