@@ -5,11 +5,11 @@ from revuo.views import ItemList, ItemView, NewItem, EditProfile, Publisher, Pub
 
 urlpatterns = patterns('',
     url(r'^$', Home.as_view()),
-    url(r'^(?P<category>publications|news|blog|media)$', ItemList.as_view()),
-    url(r'^(?P<category>[VNBP])/(?P<item_id>\d+)$', ItemView.as_view()),
+    url(r'^(?P<category>publications|news|blog)$', ItemList.as_view()),
+    url(r'^(?P<category>[NBP])/(?P<item_id>\d+)$', ItemView.as_view()),
     url(r'^staff$', Staff.as_view()),
     url(r'^staff/(?P<staff_id>\d+)$', StaffView.as_view()),
-    url(r'^restricted/(?P<category>[VNBP])/add$', NewItem.as_view()),
+    url(r'^restricted/(?P<category>[NBP])/add$', NewItem.as_view()),
     url(r'^restricted/editprofile$', EditProfile.as_view()),
     url(r'^restricted/publisher$', Publisher.as_view()),
     url(r'^restricted/publisher/(?P<category>[VNBP])/(?P<item_id>\d+)$', PublishItem.as_view()),
@@ -20,4 +20,7 @@ urlpatterns = patterns('',
     url(r'^restricted/password/ok$', 'django.contrib.auth.views.password_change_done', {}, name='password_change_done'),
     url(r'login/', 'django.contrib.auth.views.login'),
     url(r'logout/', 'django.contrib.auth.views.logout', {'next_page':'/'}),
+
+    # summernote for wysiwyg editor
+    url(r'^summernote/', include('django_summernote.urls')),
 )
